# Traefik

This stack will deploy a simple Traefik server. It will listen for http and https.

## Quickstart

With paasify:
```
paasify install mrjk/docker-compose
paasify create mrjk/docker-compose/traefik traefik
paasify build traefik
```


## See also

https://github.com/thomseddon/traefik-forward-auth#operation-modes
